@@ -30,7 +30,7 @@ def acmd(args):
 
 
 def dcmd(args):
-    from dcmd import _dcmd
+    from .dcmd import _dcmd
     _dcmd(args.alias)
 
 
@@ -49,14 +49,6 @@ def move(args):
     _move(args.project, args.destination)
 
 
-def debug(args):
-    from ._meta import cache_root, cache_commands, cache_projects
-
-    print('root:    ', cache_root, os.path.exists(cache_root))
-    print('projects:', cache_projects, os.path.exists(cache_root))
-    print('commands:', cache_commands, os.path.exists(cache_root))
-
-
 # parser
 def parser():
     p = argparse.ArgumentParser()
@@ -66,7 +58,7 @@ def parser():
     find_parser.set_defaults(func=version)
 
     find_parser = s.add_parser('find', help='find projects in a directory')
-    find_parser.add_argument('--path', '-p', help='destination directory', default='.')
+    find_parser.add_argument('path', help='destination directory', default='.')
     find_parser.set_defaults(func=find)
 
     list_parser = s.add_parser('list', help='show list of available projects')
@@ -74,31 +66,27 @@ def parser():
     list_parser.set_defaults(func=list)
 
     acmd_parser = s.add_parser('acmd', help='add a command to open projects')
-    acmd_parser.add_argument('--alias', '-a', help='command alias', required=True)
-    acmd_parser.add_argument('--body', '-b', help='command body', required=True)
+    acmd_parser.add_argument('alias', help='command alias')
+    acmd_parser.add_argument('body', help='command body')
     acmd_parser.set_defaults(func=acmd)
 
     dcmd_parser = s.add_parser('dcmd', help='delete command to open projects')
-    dcmd_parser.add_argument('--alias', '-a', help='command alias', required=True)
+    dcmd_parser.add_argument('alias', help='command alias')
     dcmd_parser.set_defaults(func=dcmd)
 
-    find_parser = s.add_parser('find', help='find projects in a directory')
-    find_parser.add_argument('--path', '-p', help='destination directory', default='.')
-    find_parser.set_defaults(func=find)
+    dcmd_parser = s.add_parser('lcmd', help='list of commands to open projects')
+    dcmd_parser.set_defaults(func=lcmd)
 
     exec_parser = s.add_parser('exec', help='open project')
-    exec_parser.add_argument('--alias', '-a', help='command alias', required=True)
-    exec_parser.add_argument('--project', '-p', help='project name or hash', required=True)
+    exec_parser.add_argument('alias', help='command alias')
+    exec_parser.add_argument('project', help='project name or hash')
     exec_parser.set_defaults(func=exec)
 
     move_parser = s.add_parser('move', help='move project to other type catalog')
-    move_parser.add_argument('--project', '-p', help='project name (hash) to moving', required=True)
-    move_parser.add_argument('--destination', '-d', help='destination', required=True)
+    move_parser.add_argument('project', help='project name (hash) to moving')
+    move_parser.add_argument('destination', help='destination')
     move_parser.set_defaults(func=move)
 
-    move_parser = s.add_parser('debug', help='for developer')
-    move_parser.set_defaults(func=debug)
-
     return p
 
 
@@ -106,7 +94,7 @@ def parser():
 def main():
 
     # ---- create cache catalog and files if they not exist
-    from ._meta import cache_root, cache_commands, cache_projects
+    from ._meta import cache_root, cache_commands, cache_projects, cache_types
 
     if not os.path.exists(cache_root):
         os.mkdir(cache_root)
@@ -119,6 +107,10 @@ def main():
         with open(cache_projects, 'w', encoding='utf-8') as file:
             file.write('{}')
 
+    if not os.path.exists(cache_types):
+        with open(cache_types, 'w', encoding='utf-8') as file:
+            file.write('{}')
+
     # ---- executing command
     p = parser()
     args = p.parse_args()
